@@ -245,7 +245,7 @@ rsvg_standard_element_start (RsvgHandle * ctx, const char *name, RsvgPropertyBag
     else if (!strcmp (name, "feBlend"))
         newnode = rsvg_new_filter_primitive_blend ();
     else if (!strcmp (name, "feColorMatrix"))
-        newnode = rsvg_new_filter_primitive_colour_matrix ();
+        newnode = rsvg_new_filter_primitive_color_matrix ();
     else if (!strcmp (name, "feComponentTransfer"))
         newnode = rsvg_new_filter_primitive_component_transfer ();
     else if (!strcmp (name, "feComposite"))
@@ -1670,6 +1670,31 @@ rsvg_handle_set_dpi_x_y (RsvgHandle * handle, double dpi_x, double dpi_y)
  * arguments are set to -1.
  *
  * Deprecated: Set up a cairo matrix and use rsvg_handle_render_cairo() instead.
+ * You can call rsvg_handle_get_dimensions() to figure out the size of your SVG,
+ * and then scale it to the desired size via Cairo.  For example, the following
+ * code renders an SVG at a specified size, scaled proportionally from whatever
+ * original size it may have had:
+ *
+ * |[<!-- language="C" -->
+ * void
+ * render_scaled_proportionally (RsvgHandle *handle, cairo_t cr, int width, int height)
+ * {
+ *     RsvgDimensionData dimensions;
+ *     double x_factor, y_factor;
+ *     double scale_factor;
+ * 
+ *     rsvg_handle_get_dimensions (handle, &dimensions);
+ * 
+ *     x_factor = (double) width / dimensions.width;
+ *     y_factor = (double) height / dimensions.height;
+ * 
+ *     scale_factor = MIN (x_factor, y_factor);
+ * 
+ *     cairo_scale (cr, scale_factor, scale_factor);
+ * 
+ *     rsvg_handle_render_cairo (handle, cr);
+ * }
+ * ]|
  **/
 void
 rsvg_handle_set_size_callback (RsvgHandle * handle,
